@@ -40,6 +40,7 @@
 #include <sys/socket.h>
 #include <netdb.h>
 #include <sys/mman.h>
+#include <libgen.h>
 
 #include <http-parser/http_parser.h>
 
@@ -1280,6 +1281,7 @@ int create_sock(Address &remote_addr, const char *addr, const char *port) {
 
   remote_addr.len = rp->ai_addrlen;
   memcpy(&remote_addr.su, rp->ai_addr, rp->ai_addrlen);
+  remote_addr.ifindex = 0;
 
   return fd;
 }
@@ -2250,9 +2252,14 @@ int parse_requests(char **argv, size_t argvlen) {
 
 std::ofstream keylog_file;
 
+namespace {
+const char *prog = "client";
+} // namespace
+
 namespace {
 void print_usage() {
-  std::cerr << "Usage: client [OPTIONS] <HOST> <PORT> [<URI>...]" << std::endl;
+  std::cerr << "Usage: " << prog << " [OPTIONS] <HOST> <PORT> [<URI>...]"
+            << std::endl;
 }
 } // namespace
 
@@ -2446,7 +2453,7 @@ Options:
               specified.
   --disable-early-data
               Disable early data.
-  --cc=(cubic|reno|bbr|bbrv2)
+  --cc=(cubic|reno|bbr)
               The name of congestion controller algorithm.
               Default: )"
             << util::strccalgo(config.cc_algo) << R"(
@@ -2513,6 +2520,10 @@ int main(int argc, char **argv) {
   const char *private_key_file = nullptr;
   const char *cert_file = nullptr;
 
+  if (argc) {
+    prog = basename(argv[0]);
+  }
+
   for (;;) {
     static int flag = 0;
     constexpr static option long_opts[] = {
@@ -2820,11 +2831,7 @@ int main(int argc, char **argv) {
           config.cc_algo = NGTCP2_CC_ALGO_BBR;
           break;
         }
-        if (strcmp("bbrv2", optarg) == 0) {
-          config.cc_algo = NGTCP2_CC_ALGO_BBR_V2;
-          break;
-        }
-        std::cerr << "cc: specify cubic, reno, bbr, or bbrv2" << std::endl;
+        std::cerr << "cc: specify cubic, reno, or bbr" << std::endl;
         exit(EXIT_FAILURE);
       case 28:
         // --exit-on-all-streams-close
